Name:           autofs
Version:        5.1.8
Release:        %mkrel 3
License:        GPLv2+
Summary:        A tool for automatically mounting and unmounting filesystems
Group:          System/Kernel and hardware
URL:            https://www.kernel.org/pub/linux/daemons/autofs
Source0:        https://www.kernel.org/pub/linux/daemons/autofs/v5/autofs-%{version}.tar.gz
Patch102:       autofs-5.0.6-separate-config-files.patch
Patch104:       autofs-5.0.7-do-not-install-init.patch
Patch105:       autofs-5.0.7-after-nss-lookup.patch
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  rpcgen
BuildRequires:  openldap-devel
BuildRequires:  krb-devel
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(libsystemd)
Conflicts:      autosmb
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
autofs is a daemon which automatically mounts filesystems when you use
them, and unmounts them later when you are not using them.  This can
include network filesystems, CD-ROMs, floppies, and so forth.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -f -i
%serverbuild
# Without the -Wl,--no-undefined which is needed to build the modules.
%define _disable_ld_no_undefined 1
%configure \
    --with-mapdir=%{_sysconfdir}/%{name} \
    --with-confdir=%{_sysconfdir}/%{name} \
    --with-sasl=yes \
    --disable-mount-locking \
    --enable-ignore-busy \
    --with-libtirpc \
    --without-hesiod \
    --with-systemd=%{_unitdir}
%make_build DONTSTRIP=1

mkdir examples
cp samples/ldap* examples
cp samples/autofs.schema examples

rm -f README.gentoo

%install
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_libdir}/autofs
mkdir -p %{buildroot}%{_mandir}/{man5,man8}
mkdir -p %{buildroot}%{_sysconfdir}
mkdir -p %{buildroot}%{_sysconfdir}/auto.master.d

%make_build install INSTALLROOT=%{buildroot}

pushd samples
%make_build install INSTALLROOT=%{buildroot}
popd

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 samples/autofs.service %{buildroot}%{_unitdir}/autofs.service

cat > README.urpmi <<EOF
Mageia RPM specific notes

setup
-----
Configuration handling in Mageia package differs from upstream one on several
points:
- the automounts daemon configuration file is %{_sysconfdir}/autofs/autofs.conf
- the autofs service configuration file is %{_sysconfdir}/sysconfig/autofs

Upgrade
-------
Map files have been moved from %{_sysconfdir} to %{_sysconfdir}/autofs. Upgrade
procedure should handle the change automatically.
LDAP usage has changed between autofs 4 and 5. The LDAP schema used has now to
be configured explicitely in autofs configuration, so as to avoid useless
queries. As this can't be handled by package upgrade procedure, you'll have to
edit your configuration manually. See auto.master(5) for details.

EOF

# tune default configuration
perl -pi -e 's|^BROWSE_MODE="no"|BROWSE_MODE="yes"|' \
    %{buildroot}%{_sysconfdir}/autofs/autofs.conf
perl -pi \
    -e 's|^/misc\t/etc/(.*)$|#/misc\t%{_sysconfdir}/%{name}/\1|;' \
    -e 's|^/net\t|#/net\t|;' \
    %{buildroot}%{_sysconfdir}/autofs/auto.master

%post
%_post_service autofs

%preun
%_preun_service autofs

%files
%doc INSTALL CHANGELOG CREDITS README* examples
%config(noreplace) %{_sysconfdir}/autofs
%{_unitdir}/autofs.service
%{_sbindir}/automount
%{_mandir}/*/*
%{_libdir}/%{name}
%{_libdir}/libautofs.so
%dir %{_sysconfdir}/auto.master.d


%changelog
* Tue Jan 03 2023 umeabot <umeabot> 5.1.8-3.mga9
+ Revision: 1929528
- Rebuild to use libldap-2.5 instead of 2.4

* Wed Mar 30 2022 umeabot <umeabot> 5.1.8-2.mga9
+ Revision: 1833759
- Mageia 9 Mass Rebuild

* Sat Jan 15 2022 mrambo3501 <mrambo3501> 5.1.8-1.mga9
+ Revision: 1768462
- version 5.1.8

* Mon Mar 08 2021 daviddavid <daviddavid> 5.1.7-1.mga9
+ Revision: 1700594
- new version: 5.1.7

* Wed Nov 25 2020 tv <tv> 5.1.6-3.mga8
+ Revision: 1649208
- BR new rpcgen pkg for bulding with glibc-2.32

* Tue Feb 18 2020 umeabot <umeabot> 5.1.6-2.mga8
+ Revision: 1539336
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
+ luigiwalser <luigiwalser>
- fix path to commented auto.misc example (mga#16195)

* Sat Dec 07 2019 shlomif <shlomif> 5.1.6-1.mga8
+ Revision: 1464998
- New version 5.1.6

* Sat Dec 29 2018 luigiwalser <luigiwalser> 5.1.5-1.mga7
+ Revision: 1346535
- 5.1.5

* Fri Sep 21 2018 umeabot <umeabot> 5.1.4-2.mga7
+ Revision: 1295170
- Mageia 7 Mass Rebuild

* Sat Feb 24 2018 shlomif <shlomif> 5.1.4-1.mga7
+ Revision: 1204842
- New version 5.1.4

* Tue Oct 24 2017 shlomif <shlomif> 5.1.3-1.mga7
+ Revision: 1173253
- New version 5.1.3

* Thu Aug 11 2016 luigiwalser <luigiwalser> 5.1.2-1.mga6
+ Revision: 1045488
- 5.1.2
- remove upstreamed patches
- rediff after-nss-lookup patch

* Sat Jan 02 2016 luigiwalser <luigiwalser> 5.1.1-2.mga6
+ Revision: 918261
- upload patches
- rebuild for libtirpc (with build fix patches from fedora)

* Mon Jun 22 2015 shlomif <shlomif> 5.1.1-1.mga6
+ Revision: 839163
- New version 5.1.1

* Wed Mar 11 2015 luigiwalser <luigiwalser> 5.1.0-4.mga5
+ Revision: 818416
- add patches from opensuse to fix CVE-2014-8169

* Wed Oct 15 2014 umeabot <umeabot> 5.1.0-3.mga5
+ Revision: 742633
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.1.0-2.mga5
+ Revision: 678058
- Mageia 5 Mass Rebuild

* Sun Aug 31 2014 luigiwalser <luigiwalser> 5.1.0-1.mga5
+ Revision: 670161
- 5.1.0
- do not patch autofs.conf.default anymore
- remove patch 103 (fixed upstream)
- rediff patch 104

* Mon Apr 28 2014 shlomif <shlomif> 5.0.9-1.mga5
+ Revision: 618595
- New version 5.0.9

* Sat Oct 19 2013 umeabot <umeabot> 5.0.7-7.mga4
+ Revision: 533493
- Mageia 4 Mass Rebuild

* Sat Aug 31 2013 luigiwalser <luigiwalser> 5.0.7-6.mga4
+ Revision: 473584
- own /etc/auto.master.d (mga#6559)

* Tue Aug 27 2013 luigiwalser <luigiwalser> 5.0.7-5.mga4
+ Revision: 472070
- rebuild for cyrus-sasl

* Fri Jan 11 2013 umeabot <umeabot> 5.0.7-4.mga3
+ Revision: 346641
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Aug 12 2012 luigiwalser <luigiwalser> 5.0.7-3.mga3
+ Revision: 280947
- fix service ordering when automounter maps are not in local files

* Mon Jul 30 2012 luigiwalser <luigiwalser> 5.0.7-2.mga3
+ Revision: 276225
- revert upstream change deleting tirpc symbol (mga #6903)

* Sun Jul 29 2012 luigiwalser <luigiwalser> 5.0.7-1.mga3
+ Revision: 275730
- no longer install SysV init script
- do not install systemd service file in wrong location (Makefile patch)
- 5.0.7

* Wed May 09 2012 pterjan <pterjan> 5.0.6-6.mga2
+ Revision: 234954
- Fix initscript's LSB header
- Fix License tag

* Sat Apr 28 2012 tmb <tmb> 5.0.6-5.mga2
+ Revision: 233592
- Require rpm-helper >= 0.24.8-1 for systemd support

* Fri Apr 27 2012 tmb <tmb> 5.0.6-4.mga2
+ Revision: 233498
- rebuild for versioned rpm-helper requires

* Tue Jan 17 2012 guillomovitch <guillomovitch> 5.0.6-3.mga2
+ Revision: 197345
- sync patches with fedora
- systemd support

* Thu Dec 29 2011 supp <supp> 5.0.6-2.mga2
+ Revision: 188759
- rebuild for mga2
+ guillomovitch <guillomovitch>
- add missing LSB headers to the init script
- new version
- drop obsoletes 4->5 transition post scripts
- spec cleanup

* Tue Feb 08 2011 ennael <ennael> 5.0.5-4.mga1
+ Revision: 49039
- imported package autofs


* Wed Dec 08 2010 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.5-4mdv2011.0
+ Revision: 616239
- update to latest patch level

* Tue Nov 30 2010 Oden Eriksson <oeriksson@mandriva.com> 5.0.5-3mdv2011.0
+ Revision: 603481
- rebuild

* Mon Mar 15 2010 Oden Eriksson <oeriksson@mandriva.com> 5.0.5-2mdv2010.1
+ Revision: 520011
- rebuilt for 2010.1

* Thu Sep 10 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.5-1mdv2010.0
+ Revision: 437529
- new version

* Sat Jul 18 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-9mdv2010.0
+ Revision: 397062
- update to latest patchlevel

* Sat May 09 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-8mdv2010.0
+ Revision: 373838
- update to latest patch level

* Fri Apr 10 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-7mdv2009.1
+ Revision: 365743
-update to latest patch level
-honor USE_MISC_DEVICE setting in initscript

* Sat Mar 14 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-6mdv2009.1
+ Revision: 354885
- update to latest official patch level

* Mon Mar 09 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-5mdv2009.1
+ Revision: 353183
- update to latest official patch level
- apply custom patches after official ones, to keep them verbatim
- tune configuration through substitutions rather than patches

* Tue Mar 03 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-4mdv2009.1
+ Revision: 347905
- update to latest official patch level

* Sun Feb 01 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-3mdv2009.1
+ Revision: 336233
- re-enable kerberos lib flag, otherwise ldap plugin doesn't work
- fix segfault when looking for host (#47423)

* Fri Jan 30 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-2mdv2009.1
+ Revision: 335551
- drop sasl detection patch, uneeded anymore
- drop ldap detection patch, available upstream
- update to latest upstream patch level

* Wed Dec 03 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.4-1mdv2009.1
+ Revision: 309829
- new version
- rediff configuration files separation patch
- drop merged patches

* Tue Sep 09 2008 Olivier Thauvin <nanardon@mandriva.org> 5.0.3-7mdv2009.0
+ Revision: 282880
- convert requires kernel... to conflicts, then avoiding to require kernel in virtual system

* Wed Jul 02 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.3-6mdv2009.0
+ Revision: 230676
- no dependency on nfs-utils in package (automount is not nfs-specific)
- no dependency on nfs-common in initscript (automound doesn't requires it)
- update to latest official patch set
- fix init script dependencies

* Tue May 20 2008 Stefan van der Eijk <stefan@mandriva.org> 5.0.3-5mdv2009.0
+ Revision: 209577
- rebuild, give it annother shot...
- sync patches to fix expire issue

* Fri Jan 25 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.3-4mdv2008.1
+ Revision: 158131
- sync with latest upstream patches (fix #37107)

  + Olivier Blin <oblin@mandriva.com>
    - update to new upstream version of basedn-with-spaces fix

* Mon Jan 21 2008 Olivier Blin <oblin@mandriva.com> 5.0.3-2mdv2008.1
+ Revision: 155518
- fix parsing mount options with LDAP mounts (upstream patch)

* Tue Jan 15 2008 Olivier Blin <oblin@mandriva.com> 5.0.3-1mdv2008.1
+ Revision: 152545
- workaround upstream ldap-page-control check by adding -lpthread
- add upstream ldap-page-control-configure-fix patch
- rediff comment-default-master-map patch
- 5.0.3
- remove upstream 5.0.2 patches
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Nov 17 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-10mdv2008.1
+ Revision: 109442
- fix kerberos linking, and re-enable sasl support
- patch45: fix build without sasl

* Mon Nov 12 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-9mdv2008.1
+ Revision: 108335
- add libxml2-devel build dependency, but disable sasl build for now, as it breaks ldap module, and is known to be non-functional anyway
- add available upstream patches

* Tue Oct 09 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-8mdv2008.1
+ Revision: 96243
- soft dependency on ypbind in init script

* Mon Oct 01 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-7mdv2008.0
+ Revision: 94155
- don't deal with /etc/modules.conf, this file isn't used anymore

* Sat Sep 15 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-6mdv2008.0
+ Revision: 86323
- add a reference to README.urpmi in configuration files comments
- don't ship upstream init script man page
- more explicit description of differences with upstream configuration
- patch 103: ensure configuration file remains /etc/autofs/autofs.conf

* Tue Sep 11 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-5mdv2008.0
+ Revision: 84307
- re-enable sasl build

* Mon Sep 10 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-4mdv2008.0
+ Revision: 84274
- update to latest upstream patch set
- fix configuration file name to autofs.conf
- disable sasl support, as it doesn't build

* Mon Jul 30 2007 Andreas Hasenack <andreas@mandriva.com> 5.0.2-3mdv2008.0
+ Revision: 56585
- added digital signature for tarball
- really enable sasl build (we already buildrequire it)

* Thu Jul 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-2mdv2008.0
+ Revision: 53710
- build requires sasl-devel
- set default browse mode to reduce cpu usage (fix #31901)

* Thu Jul 05 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.2-1mdv2008.0
+ Revision: 48725
- new version
  drop patches 100, 101, 102 and 104 (merged upstream)
  rediff patch 102

* Wed Jul 04 2007 Andreas Hasenack <andreas@mandriva.com> 5.0.1-6mdv2008.0
+ Revision: 48210
- rebuild with new serverbuild macro (-fstack-protector-all)
- autoconf-2.5x is gone, use plain autoconf

* Thu Jun 07 2007 Anssi Hannula <anssi@mandriva.org> 5.0.1-5mdv2008.0
+ Revision: 36155
- rebuild with correct optflags


* Wed Feb 28 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-2mdv2007.0
+ Revision: 130155
- init script harmonization
- init script harmonization

* Tue Feb 20 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-1mdv2007.1
+ Revision: 122961
- fix release tag
- final 5.0.1 version

* Mon Feb 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc3.2mdv2007.1
+ Revision: 122733
- update to latest patch level
- fix init script indentation
  add condrestart and condreload actions

* Fri Jan 12 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc3.1mdv2007.1
+ Revision: 107864
- new version (should fix #28113)
  rediff configuration patches
  drop ldap fix patch (merged upstream)
- Import autofs

* Wed Sep 13 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc2.2mdv2007.0
- more dependencies in init script

* Tue Sep 05 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc2.1mdv2007.0
- new version
- fix reload function in initscript (#25128)
- changed README.mdv to README.urpmi
- add some notes about LDAP handling change

* Sat Sep 02 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.6mdv2007.0
- comment default master map entries
- soft dependencies against ldap in init script

* Tue Aug 29 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.5mdv2007.0
- buildrequires

* Tue Aug 29 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.4mdv2007.0
- more cautious file testing during upgrade (fix #24768)

* Sat Aug 26 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.3mdv2007.0
- fix ldap lookup when only a map name is given

* Sat Aug 26 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.2mdv2007.0
- fix prevention of stripping

* Fri Aug 25 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.1mdv2007.0
- new version
- handle 4.x -> 5.x configuration file location change
- add status option to init script

* Fri Jun 30 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.0-0.beta6.1mdv2007.0
- new version
- move configuration files in /etc/autofs
- drop patches 1 and 9 (merged upstream)
- drop patch 2, 3, 7 and 12 (useless or undesirable according to developpers)
- use -DDONTSTRIP instead of -DDEBUG to prevent stripping before installation

* Sat Apr 29 2006 Stefan van der Eijk <stefan@eijk.nu> 4.1.4-9mdk
- Rebuild for sparc

* Thu Jan 26 2006 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-8mdk
- multimount patch (Andrey Borzenkov <arvidjaar@mail.ru>)
- various fixes in init script (Quel Qun <kelk1@comcast.net>)
- more init script cleanup

* Thu Jan 19 2006 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-6mdk
- new custom initscript, with parallel init and timeout support
- move executable scripts from /etc to /usr/lib/autofs
- drop redundant portmap requires
- drop useless README files

* Mon Nov 14 2005 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-5mdk
- define -DLDAP_DEPRECATED (fix #19605)
- make sure -g and standard optimisation flags are used
- cleanup samples file in documentation
- don't mark scripts as executable (TODO: install them under /usr/lib/autofs)
- drop non-applied patches

* Fri Nov 04 2005 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-4mdk
- spec cleanup
- more macros

* Wed Aug 31 2005 Oden Eriksson <oeriksson@mandriva.com> 4.1.4-3mdk
- rebuilt against new openldap-2.3.6 libs
- misc rpmlint fixes

* Thu Jul 14 2005 Nicolas Lécureuil <neoclust@mandriva.org> 4.1.4-2mdk
- Fix conflicts
- preReq => Requires(pre)

* Mon May 23 2005 Stefan van der Eijk <stefan@eijk.nu> 4.1.4-1mdk
- 4.1.4
- start autofs after named (45 --> 60)
- rediffed patch 3 (auto-master)
- rediffed patch 4 (init-redhat-only) now only changes the runlevel config
- rediffed patch 8 (stripdash)
- remove patch 20 (bad_chdir) merged upstream
- remove patch 21 (mtab_lock) merged upstream
- remove patch 22 (non_block_ping) merged upstream
- disable patch 23 (replicated_server_select) more or less merged upstream
- rediffed patch 24 (signal-race-fix)
- disable patch 25 (sock-leak-fix) more or less merged upstream
- remove patch 26 (strict) merged upstream
- spec file cosmetics (%%mkrel, remove %%ver, no TODO file in doc, add auto.smb)

* Fri Feb 04 2005 Buchan Milne <bgmilne@linux-mandrake.com> 4.1.3-3mdk
- rebuild for ldap2.2_7

* Tue Nov 23 2004 Stefan van der Eijk <stefan@mandrake.org> 4.1.3-2mdk
- let autofs start after the ldap server

* Tue Nov 23 2004 Stefan van der Eijk <stefan@mandrake.org> 4.1.3-1mdk
- 4.1.3
- rediff patch 4
- add 4.1.3 patches

* Wed May 05 2004 Juan Quintela <quintela@mandrakesoft.com> 4.1.2-1mdk
- merge with redhat 4.1.2-2.
- actualize spec file.
- lots of patches included upstream or irrelevant.
- 4.1.2.

* Wed Apr 07 2004 Stefan van der Eijk <stefan@eijk.nu> 4.0.0-0.22mdk
- Patch18: ldapv3 patch from mc@suse.de
- Source1: replace with suse's ldapv3 enabled one
- from Michael Scherer : clean some requires

